import { useMemo } from "react";
import {
  EllipsisText,
  InternalLink,
  Table,
  SimpleAccordion
} from "@ess-ics/ce-ui-common";
import { Typography, Stack } from "@mui/material";
import { getNoOfIOCs, getNoOfHosts, isBatchJob } from "./JobUtils";
import { JobRevisionChip } from "./JobRevisionChip";
import { JobHost } from "./JobHost";
import { JobDetails, JobDetailsEntry } from "../../store/deployApi";

const columns = [
  {
    field: "ioc",
    headerName: "IOC",
    flex: 1
  },
  {
    field: "revision",
    headerName: "Revision",
    flex: 1
  },
  {
    field: "host",
    headerName: "Host",
    flex: 1
  }
];

const createRow = (job: JobDetailsEntry) => {
  const { iocId, iocName, host, gitReference, gitProjectId } = job;
  return {
    id: `${iocId}${host?.hostId}`,
    ioc: (
      <InternalLink
        to={`/iocs/${iocId}`}
        label={`Ioc details, ${iocName}`}
        width="100%"
      >
        <EllipsisText>{iocName}</EllipsisText>
      </InternalLink>
    ),
    host: <JobHost job={job} />,
    revision: gitReference && gitProjectId && (
      <JobRevisionChip
        gitReference={gitReference}
        gitProjectId={gitProjectId}
      />
    )
  };
};

export const JobDetailsTable = ({ operation }: { operation: JobDetails }) => {
  const isBatchOperation = isBatchJob(operation.action);

  const noOfIOCs = useMemo(() => {
    if (isBatchOperation) {
      return getNoOfIOCs(operation.jobs);
    }
  }, [operation, isBatchOperation]);

  const noOfHosts = useMemo(() => {
    if (isBatchOperation) {
      return getNoOfHosts(operation.jobs);
    }
  }, [operation, isBatchOperation]);

  return (
    <>
      {isBatchJob(operation.action) ? (
        <SimpleAccordion
          summary={
            <Stack
              flexDirection="row"
              alignItems="end"
              sx={{ width: "100%" }}
              gap={1}
            >
              {" "}
              <Typography
                component="h2"
                variant="h3"
              >
                Batch
              </Typography>
              <Typography
                variant="body2"
                sx={{ fontWeight: "600", marginRight: "10px" }}
              >
                {noOfIOCs} {noOfIOCs && noOfIOCs > 1 ? "IOCs" : "IOC"}
                {", "}
                {noOfHosts} {noOfHosts && noOfHosts > 1 ? "Hosts" : "Host"}
              </Typography>
            </Stack>
          }
        >
          <Table
            columns={columns}
            disableColumnSorting
            rows={operation?.jobs?.map((job) => createRow(job))}
          />
        </SimpleAccordion>
      ) : (
        <Table
          columns={columns}
          disableColumnSorting
          rows={[operation].map((job) => createRow(job))}
        />
      )}
    </>
  );
};
